@@ -257,7 +257,7 @@ void PrinterChanged(GtkWidget *widget,gpointer data)
 	if(DEBUG)
 		printf("Printer changed: %s\n",(char *)tmp);
 
-	if(tmp[0]==(char)NULL) {
+	if(tmp[0]==(uintptr_t)NULL) {
 		if(DEBUG) printf("Skipping emptry selection !\n");
 		return;
 	}
@@ -276,7 +276,7 @@ void PrinterChanged(GtkWidget *widget,gpointer data)
 		}
 		i1++;
 	}
-	while(PrinterNames[i1][0] != (unsigned char)NULL);
+	while(PrinterNames[i1][0] != (uintptr_t)NULL);
 
 	if(strangeerrortrap == 0)
 	{
@@ -529,7 +529,8 @@ void PrinterNumCopies(GtkWidget *container)
         gtk_widget_show(hbox);
 
 	/* Spinbutton */
-	adjust = gtk_adjustment_new (1.0, 1.0, 999, 1.0, 1.0, 1.0);
+	//adjust = gtk_adjustment_new (1.0, 1.0, 999, 1.0, 1.0, 1.0);
+  adjust = gtk_adjustment_new (1.0, 1.0, 999, 1.0, 1.0,0);
 	printerNumField=gtk_spin_button_new (GTK_ADJUSTMENT(adjust), 1.0, 0);
 	gtk_widget_set_usize(printerNumField, 3*16, -1);
 	gtk_box_pack_start(GTK_BOX(hbox), printerNumField, FALSE, FALSE, 0);
