@@ -57,9 +57,9 @@
 #include "text.h"
 
 GtkWidget *tabs;
-unsigned char Range[MAXRANGEENTRY+1];
-unsigned char JobName[MAX_JOB_NAME_LENGTH+1];
-unsigned char ExtraOpt[MAX_EXTRAOPT+1];
+char Range[MAXRANGEENTRY+1];
+char JobName[MAX_JOB_NAME_LENGTH+1];
+char ExtraOpt[MAX_EXTRAOPT+1];
 int ignore_stdin;
 int clearfilelist,exitonprint;
 int saveonexit,rememberprinter,remembertab,tabtoopen;
@@ -102,14 +102,14 @@ double ggamma;
 unsigned int cppvalue,lpivalue,cpivalue;
 unsigned int topmargin, bottommargin, leftmargin, rightmargin;
 int MediaSizeSelected, MediaTypeSelected, MediaSourceSelected;
-unsigned char filesToPrint[MAXPRINTFILES][MAXPATH+1];
-unsigned char filesToPrintAnz;
-unsigned char fileOpenPath[MAXPATH+1];
-unsigned char confdir[MAXPATH+1];
-unsigned char GTKLPRC[MAXPATH+1],HELP_HOME[MAXPATH+1];
-unsigned char BROWSER[MAXPATH+1];
-unsigned char HELPURL[MAXPATH+1];
-unsigned char GTKLPQCOM[MAXPATH+1];
+char filesToPrint[MAXPRINTFILES][MAXPATH+1];
+char filesToPrintAnz;
+char fileOpenPath[MAXPATH+1];
+char confdir[MAXPATH+1];
+char GTKLPRC[MAXPATH+1],HELP_HOME[MAXPATH+1];
+char BROWSER[MAXPATH+1];
+char HELPURL[MAXPATH+1];
+char GTKLPQCOM[MAXPATH+1];
 int textwrap;
 char PortString[MAX_PORT+11];
 int hasAskedPWD;
@@ -136,7 +136,7 @@ int main(int argc,char *argv[])
 	int calledLpr;
 	int calledLp;
 	int forceX;
-	unsigned char Path[MAXPATH+1];
+	char Path[MAXPATH+1];
 	char *z1;
 	char tmpenv[MAX_SERVER_NAME+13];
 
@@ -152,7 +152,7 @@ int main(int argc,char *argv[])
 
 	dialog=(GtkWidget *)NULL;
 
-	JobName[0]=(unsigned char)NULL;
+	JobName[0]=(uintptr_t)NULL;
 
 	ignore_stdin=0;
 	printerPPD=NULL;
@@ -161,12 +161,12 @@ int main(int argc,char *argv[])
 
 	conflict_active=0;
 
-	BROWSER[0]=(char)NULL;
-	HELPURL[0]=(char)NULL;
-	GTKLPQCOM[0]=(char)NULL;
+	BROWSER[0]=(uintptr_t)NULL;
+	HELPURL[0]=(uintptr_t)NULL;
+	GTKLPQCOM[0]=(uintptr_t)NULL;
 
-	nupLayout[0]=(char)NULL;
-	borderType[0]=(char)NULL;
+	nupLayout[0]=(uintptr_t)NULL;
+	borderType[0]=(uintptr_t)NULL;
 
 	textwrap=0;
 
@@ -212,11 +212,11 @@ int main(int argc,char *argv[])
 	/*--- Get Programm Options ---*/
   num_commandline_opts=0;
   commandline_opts=NULL;
-	DEF_PRN[0]=(unsigned char)NULL;
-	confdir[0]=(unsigned char)NULL;
-	ServerName[0]=(char)NULL;
-	UserName[0]=(char)NULL;
-	Path[0]=(unsigned char)NULL;
+	DEF_PRN[0]=(uintptr_t)NULL;
+	confdir[0]=(uintptr_t)NULL;
+	ServerName[0]=(uintptr_t)NULL;
+	UserName[0]=(uintptr_t)NULL;
+	Path[0]=(uintptr_t)NULL;
 	ReallyPrint=1;
 	needFileSelection = 1;
 	cmdNumCopies=-1;
@@ -519,7 +519,7 @@ int main(int argc,char *argv[])
 		{
 			if(filesToPrintAnz<MAXPRINTFILES)
 			{
-				strncpy(filesToPrint[filesToPrintAnz++],argv[optind++],(size_t)MAXPATH);
+				strncpy(filesToPrint[(unsigned char)filesToPrintAnz++],argv[optind++],(size_t)MAXPATH);
 			}
 			else
 			{
@@ -568,7 +568,7 @@ int main(int argc,char *argv[])
 
 
 	/* Try to get connected to Server */
-	if(ServerName[0]==(char)NULL)
+	if(ServerName[0]==(uintptr_t)NULL)
 	{
 		if(DEBUG)
 			printf("No Servername given, searching...\n");
@@ -623,7 +623,7 @@ int main(int argc,char *argv[])
 	}
 
 	/* CWD */
-        fileOpenPath[0]=(unsigned char)NULL;
+        fileOpenPath[0]=(uintptr_t)NULL;
         getcwd(fileOpenPath,MAXPATH);
 	strncat(fileOpenPath,"/",(size_t)MAXPATH);
 	if(DEBUG)
@@ -641,7 +641,7 @@ int main(int argc,char *argv[])
 	if(DEBUG)
 		printf("Default-Printer(2): %s\n",DEF_PRN);
 
-	if(DEF_PRN[0] == (unsigned char)NULL)
+	if(DEF_PRN[0] == (uintptr_t)NULL)
 	{
 		if(DEBUG)
 			printf("PROG-ERROR: No Printer found to use for default !\n");
