@@ -119,14 +119,14 @@ void getPaths(void)
 	char *z1;
 
 
-	GTKLPRC[0]=(unsigned char)NULL;
+	GTKLPRC[0]=(uintptr_t)NULL;
 
-	if(confdir[0] == (unsigned char)NULL)
+	if(confdir[0] == (uintptr_t)NULL)
 	{
 		if(DEBUG)
 			printf("No conffile given at command-line !\n");
 
-		if(getenv("HOME")==(unsigned char)NULL)
+		if(getenv("HOME")==(uintptr_t)NULL)
 		{
 			if(DEBUG)
 				printf("ERROR: No Home-Variable set !\n");
@@ -142,7 +142,7 @@ void getPaths(void)
 		z1+=strlen((char*)confdir);
 		z1--;
 		if(*z1=='/')
-			*z1=(char)NULL;
+			*z1=(uintptr_t)NULL;
 	}
 
 	snprintf((char*)GTKLPRC,(size_t)MAXPATH,"%s/%s",confdir,GTKLPRC_GLOBAL);
@@ -165,7 +165,7 @@ void getBannerList(char *printername)
 	
 	z1=strchr(printername,'/');
 	if(z1 != NULL)
-		*z1=(char)NULL;
+		*z1=(uintptr_t)NULL;
 
 	snprintf(URI,(size_t)MAX_URI,"ipp://%s/printers/%s",ServerName,printername);
 
@@ -219,10 +219,10 @@ void getOptions(char *printername,int which)
 	int i1,hasrc,nohome,ppdOptAnz;
 	int needNew=0;
 	int whichfile=0;
-	unsigned char printpath[MAXPATH+1],globalpath[MAXPATH+1];
-	unsigned char printpath_g[MAXPATH+1],globalpath_g[MAXPATH+1];
-	unsigned char tmp[MAXLINE+1];
-	unsigned char iprintername[DEF_PRN_LEN+1];
+	char printpath[MAXPATH+1],globalpath[MAXPATH+1];
+	char printpath_g[MAXPATH+1],globalpath_g[MAXPATH+1];
+	char tmp[MAXLINE+1];
+	char iprintername[DEF_PRN_LEN+1];
 	FILE *file = NULL;
 	int num_printer;
 	cups_dest_t *all_printer;
@@ -244,7 +244,7 @@ void getOptions(char *printername,int which)
 
 	z1=strchr(printername,'/');
 	if(z1 != NULL) {
-		*z1=(char)NULL;
+		*z1=(uintptr_t)NULL;
 		snprintf(iprintername,(size_t)DEF_PRN_LEN,"%s\\%s",printername,z1+1);
 		*z1='/';
 		z1++;
@@ -265,13 +265,13 @@ void getOptions(char *printername,int which)
 	{
 		nohome=0;
 		ppdOptAnz=-1;
-		printpath[0]=(unsigned char)NULL;
-		globalpath[0]=(unsigned char)NULL;
-		printpath_g[0]=(unsigned char)NULL;
-		globalpath_g[0]=(unsigned char)NULL;
+		printpath[0]=(uintptr_t)NULL;
+		globalpath[0]=(uintptr_t)NULL;
+		printpath_g[0]=(uintptr_t)NULL;
+		globalpath_g[0]=(uintptr_t)NULL;
 
 
-		if(getenv("HOME")==(unsigned char)NULL)
+		if(getenv("HOME")==(uintptr_t)NULL)
 		{
 			if(DEBUG)
 				printf("ERROR: No Home-Variable set !\n");
@@ -314,7 +314,7 @@ void getOptions(char *printername,int which)
                 wantLandscape=0;
                 wantRange=0;
 								wantReverseOutputOrder=0;
-                Range[0]=(unsigned char)NULL;
+                Range[0]=(uintptr_t)NULL;
                 rangeType=2;
 								mirroroutput=0;
                 sheetsType=1;
@@ -343,21 +343,21 @@ void getOptions(char *printername,int which)
                 hpgl2fit=0;
                 hpgl2pen=1000;
                 wantraw=0;
-                ExtraOpt[0]=(unsigned char)NULL;
+                ExtraOpt[0]=(uintptr_t)NULL;
                 viewable[0]=1;
                 viewable[1]=1;
                 viewable[2]=1;
                 viewable[3]=1;
                 viewable[4]=1;
 		viewable[5]=1;
-		if(UserName[0] == (char)NULL)
+		if(UserName[0] == (uintptr_t)NULL)
 		{
 			if((strlen((char *)cupsUser()) < MAX_USERNAME))
 				strncpy(UserName,(char *)cupsUser(),(size_t)MAX_USERNAME);
 			else
-				UserName[0]=(char)NULL;
+				UserName[0]=(uintptr_t)NULL;
 		}
-		passWord[0]=(char)NULL;
+		passWord[0]=(uintptr_t)NULL;
 		hasAskedPWD=0;
 
 		hasrc=0;
@@ -404,7 +404,7 @@ void getOptions(char *printername,int which)
 		instance=strchr(printername,'/');
 		if(instance != NULL)
 		{
-			*instance=(char)NULL;
+			*instance=(uintptr_t)NULL;
 			if(DEBUG)
 				printf("Try to get printer: %s/%s\n",printername,instance+1);
 			act_printer = cupsGetDest(printername, instance+1, num_printer, all_printer);
@@ -442,7 +442,7 @@ void getOptions(char *printername,int which)
 			NumberOfCopies=cmdNumCopies;
 		}
 		else {
-			if(cupsGetOption("copies",act_printer->num_options,act_printer->options) != (char)NULL) 
+			if(cupsGetOption("copies",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) 
 				NumberOfCopies=atoi(cupsGetOption("copies",act_printer->num_options,act_printer->options));
 			oldnumcopies=NumberOfCopies;
 		}
@@ -460,108 +460,108 @@ void getOptions(char *printername,int which)
 		}
 
 
-		if(cupsGetOption("landscape",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("landscape",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			if(strcasecmp(cupsGetOption("landscape",act_printer->num_options,act_printer->options),"true") == 0) 
 				wantLandscape=1;
 		}
 
-		if(cupsGetOption("page-ranges",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("page-ranges",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 				wantRange=1;
 				strncpy(Range,cupsGetOption("page-ranges",act_printer->num_options,act_printer->options),(size_t)MAXRANGEENTRY);
 		}
 
-		if(cupsGetOption("outputorder",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("outputorder",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			if(strcasecmp(cupsGetOption("outputorder",act_printer->num_options,act_printer->options),"normal") == 0)
 				wantReverseOutputOrder=0;
 			if(strcasecmp(cupsGetOption("outputorder",act_printer->num_options,act_printer->options),"reverse") == 0)
 				wantReverseOutputOrder=1;
 		}
 
-		if(cupsGetOption("page-set",act_printer->num_options,act_printer->options) != (char)NULL) {	
+		if(cupsGetOption("page-set",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {	
 			if(strcasecmp(cupsGetOption("page-set",act_printer->num_options,act_printer->options),"even") == 0)
 				rangeType=1;
 			if(strcasecmp(cupsGetOption("page-set",act_printer->num_options,act_printer->options),"odd") == 0)
 				rangeType=0;
 		}
 
-		if(cupsGetOption("number-up",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("number-up",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			sheetsType=atoi(cupsGetOption("number-up",act_printer->num_options,act_printer->options));
 			if((sheetsType != 1) & (sheetsType != 2) & (sheetsType != 3) & (sheetsType != 4) & (sheetsType != 6) & (sheetsType != 9) & (sheetsType != 16))
 				sheetsType=1;
 		}
 
-		if(cupsGetOption("number-up-layout",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("number-up-layout",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			strncpy(nupLayout,cupsGetOption("number-up-layout",act_printer->num_options,act_printer->options),(size_t)4);
 		}
 
-		if(cupsGetOption("mirror",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("mirror",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			if(strcasecmp(cupsGetOption("mirror",act_printer->num_options,act_printer->options),"true") == 0)
 				mirroroutput=1;
 		}
 
-		if(cupsGetOption("page-border",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("page-border",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			strncpy(borderType,cupsGetOption("page-border",act_printer->num_options,act_printer->options),(size_t)12);
 		}
 
-		if(cupsGetOption("brightness",act_printer->num_options,act_printer->options) != (char)NULL)
+		if(cupsGetOption("brightness",act_printer->num_options,act_printer->options) != (uintptr_t)NULL)
 			brightness=atof(cupsGetOption("brightness",act_printer->num_options,act_printer->options));
 
-		if(cupsGetOption("gamma",act_printer->num_options,act_printer->options) != (char)NULL)
+		if(cupsGetOption("gamma",act_printer->num_options,act_printer->options) != (uintptr_t)NULL)
 			ggamma=atof(cupsGetOption("gamma",act_printer->num_options,act_printer->options));
 
-		if(cupsGetOption("cpi",act_printer->num_options,act_printer->options) != (char)NULL)
+		if(cupsGetOption("cpi",act_printer->num_options,act_printer->options) != (uintptr_t)NULL)
 			cpivalue=(unsigned)atol(cupsGetOption("cpi",act_printer->num_options,act_printer->options));
 
-		if(cupsGetOption("lpi",act_printer->num_options,act_printer->options) != (char)NULL)
+		if(cupsGetOption("lpi",act_printer->num_options,act_printer->options) != (uintptr_t)NULL)
 			lpivalue=(unsigned)atol(cupsGetOption("lpi",act_printer->num_options,act_printer->options));
 
-		if(cupsGetOption("columns",act_printer->num_options,act_printer->options) != (char)NULL)
+		if(cupsGetOption("columns",act_printer->num_options,act_printer->options) != (uintptr_t)NULL)
 			cppvalue=(unsigned)atol(cupsGetOption("columns",act_printer->num_options,act_printer->options));
 
-		if(cupsGetOption("page-top",act_printer->num_options,act_printer->options) != (char)NULL)
+		if(cupsGetOption("page-top",act_printer->num_options,act_printer->options) != (uintptr_t)NULL)
 			topmargin=(unsigned)atol(cupsGetOption("page-top",act_printer->num_options,act_printer->options));
 
-		if(cupsGetOption("page-bottom",act_printer->num_options,act_printer->options) != (char)NULL)
+		if(cupsGetOption("page-bottom",act_printer->num_options,act_printer->options) != (uintptr_t)NULL)
 			bottommargin=(unsigned)atol(cupsGetOption("page-bottom",act_printer->num_options,act_printer->options));
 
-		if(cupsGetOption("page-left",act_printer->num_options,act_printer->options) != (char)NULL)
+		if(cupsGetOption("page-left",act_printer->num_options,act_printer->options) != (uintptr_t)NULL)
 			leftmargin=(unsigned)atol(cupsGetOption("page-left",act_printer->num_options,act_printer->options));
 
-		if(cupsGetOption("page-right",act_printer->num_options,act_printer->options) != (char)NULL)
+		if(cupsGetOption("page-right",act_printer->num_options,act_printer->options) != (uintptr_t)NULL)
 			rightmargin=(unsigned)atol(cupsGetOption("page-right",act_printer->num_options,act_printer->options));
 
-		if(cupsGetOption("prettyprint",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("prettyprint",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			if(strcasecmp(cupsGetOption("prettyprint",act_printer->num_options,act_printer->options),"true") == 0)
 				prettyprint=1;
 		}
 
-		if(cupsGetOption("wrap",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("wrap",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			if(strcasecmp(cupsGetOption("wrap",act_printer->num_options,act_printer->options),"true") == 0)
 				textwrap=1;
 		}
 
-		if(cupsGetOption("scaling",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("scaling",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			imageScalingScalingValue=atof(cupsGetOption("scaling",act_printer->num_options,act_printer->options));
 			imageScalingType=1;	
 		}	
 
-		if(cupsGetOption("natural-scaling",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("natural-scaling",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			imageScalingNaturalValue=atof(cupsGetOption("natural-scaling",act_printer->num_options,act_printer->options));
 			imageScalingType=2;
 		}
 
-		if(cupsGetOption("ppi",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("ppi",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			imageScalingPPIValue=atof(cupsGetOption("ppi",act_printer->num_options,act_printer->options));
 			imageScalingType=3;
 		}
 
-		if(cupsGetOption("hue",act_printer->num_options,act_printer->options) != (char)NULL) 
+		if(cupsGetOption("hue",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) 
 			hue=atof(cupsGetOption("hue",act_printer->num_options,act_printer->options));
 
-		if(cupsGetOption("saturation",act_printer->num_options,act_printer->options) != (char)NULL) 
+		if(cupsGetOption("saturation",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) 
 			sat=atof(cupsGetOption("saturation",act_printer->num_options,act_printer->options));
 
-		if(cupsGetOption("position",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("position",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			if(strcasecmp(cupsGetOption("position",act_printer->num_options,act_printer->options),"left") == 0) {
 				ImagePos[0]=0;
 				ImagePos[1]=1;
@@ -600,34 +600,34 @@ void getOptions(char *printername,int which)
 			}
 		}
 
-		if(cupsGetOption("blackplot",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("blackplot",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			if(strcasecmp(cupsGetOption("blackplot",act_printer->num_options,act_printer->options),"true") == 0)
 				hpgl2black=1;
 		}
 
-		if(cupsGetOption("fitplot",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("fitplot",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			if(strcasecmp(cupsGetOption("fitplot",act_printer->num_options,act_printer->options),"true") == 0)
 				hpgl2fit=1;
 		}
 
-		if(cupsGetOption("penwidth",act_printer->num_options,act_printer->options) != (char)NULL)
+		if(cupsGetOption("penwidth",act_printer->num_options,act_printer->options) != (uintptr_t)NULL)
 			hpgl2pen=(unsigned)atol(cupsGetOption("penwidth",act_printer->num_options,act_printer->options));
 
-		if(cupsGetOption("job-sheets",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("job-sheets",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			strncpy(tmp,cupsGetOption("job-sheets",act_printer->num_options,act_printer->options),(size_t)MAXLINE);
 			z1=strchr(tmp,',');
-			if(z1 == (char)NULL) {
+			if(z1 == (uintptr_t)NULL) {
 				strncpy(PrinterBannerStart[PrinterChoice],tmp,(size_t)MAXLINE);	
 			}
 			else {
-				*z1=(char)NULL;
+				*z1=(uintptr_t)NULL;
 				z1++;
 				strncpy(PrinterBannerStart[PrinterChoice],tmp,(size_t)MAXLINE);
 				strncpy(PrinterBannerEnd[PrinterChoice],z1,(size_t)MAXLINE);
 			}
 		}
 
-		if(cupsGetOption("raw",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("raw",act_printer->num_options,act_printer->options) != (uintptr_t)NULL) {
 			if(strcasecmp(cupsGetOption("raw",act_printer->num_options,act_printer->options),"true") == 0)
 			wantraw=1;
 		}
@@ -639,36 +639,36 @@ void getOptions(char *printername,int which)
 			if(DEBUG)
 				printf("Loading defaults for %s\n",printername);
 
-	    tmp[0]=(unsigned char)NULL;
+	    tmp[0]=(uintptr_t)NULL;
       i1=freadline(file,tmp,MAXLINE);
-			if((JobName[0] == (unsigned char)NULL) && (tmp[0] != '-'))
+			if((JobName[0] == (uintptr_t)NULL) && (tmp[0] != '-'))
       	strncpy(JobName,str2str(tmp),(size_t)MAX_JOB_NAME_LENGTH);
 
-      tmp[0]=(unsigned char)NULL;
+      tmp[0]=(uintptr_t)NULL;
 	    i1=freadline(file,tmp,MAXLINE);
       if(tmp[0] != '-')
       	strncpy(ExtraOpt,str2str(tmp),(size_t)MAX_EXTRAOPT);
 	    else
-        ExtraOpt[0]=(unsigned char)NULL;
+        ExtraOpt[0]=(uintptr_t)NULL;
 
 		  fscanf(file,"%i %i %i %i %i %i\n",&viewable[0],&viewable[1],&viewable[2],&viewable[3],&viewable[4],&viewable[5]);
 
-			tmp[0]=(unsigned char)NULL;
+			tmp[0]=(uintptr_t)NULL;
 			freadline(file,tmp,MAXLINE);
-			if(tmp[0] != (unsigned char)NULL)
+			if(tmp[0] != (uintptr_t)NULL)
 			{
 				if((strlen(str2str(tmp)) < MAX_USERNAME) && (tmp[0] != 255))
 					strncpy(UserName,str2str(tmp),(size_t)MAX_USERNAME);
 				else
-					UserName[0]=(char)NULL;
+					UserName[0]=(uintptr_t)NULL;
 				cupsSetUser((const char *)UserName);
 			}
-			tmp[0]=(unsigned char)NULL;
+			tmp[0]=(uintptr_t)NULL;
 			freadline(file,tmp,MAXLINE);
 			if((strlen(str2str(tmp)) < MAX_PASSLEN) && (tmp[0] != 255))
 				strncpy(passWord,str2str(tmp),(size_t)MAX_PASSLEN);
 			else
-				passWord[0]=(char)NULL;
+				passWord[0]=(uintptr_t)NULL;
 			hasAskedPWD=0;
 															
 			fclose(file);
@@ -721,7 +721,7 @@ void getOptions(char *printername,int which)
 		jobidonexit=0;
 		strncpy(BROWSER,DEF_BROWSER_CMD,(size_t)MAXPATH);
 		strncpy(HELPURL,DEF_HELP_HOME,(size_t)MAXPATH);
-		GTKLPQCOM[0]=(char)NULL;
+		GTKLPQCOM[0]=(uintptr_t)NULL;
 		wantconst=0;
 #if GTK_MAJOR_VERSION != 1
 		mainWindowHeight=0; 
@@ -764,11 +764,11 @@ void getOptions(char *printername,int which)
 	        {
         	        if(DEBUG)
                 	        printf("Loading global defaults\n");
-	                tmp[0]=(unsigned char)NULL; 
+	                tmp[0]=(uintptr_t)NULL; 
         	        freadline(file,tmp,MAXLINE);	/* last Printer */
 
 						fscanf(file,"%i\n",&rememberprinter);
-						if((rememberprinter == 1) && DEF_PRN[0] == (unsigned char)NULL)
+						if((rememberprinter == 1) && DEF_PRN[0] == (uintptr_t)NULL)
 						{
 							if(DEBUG)
 								printf("set printer to remembered: %s\n",tmp);
@@ -783,13 +783,13 @@ void getOptions(char *printername,int which)
        			fscanf(file,"%i\n",&clearfilelist);
 	       		fscanf(file,"%i\n",&exitonprint);
 			fscanf(file,"%i\n",&jobidonexit);
-			tmp[0]=(unsigned char)NULL;
+			tmp[0]=(uintptr_t)NULL;
 			freadline(file,tmp,MAXLINE);
 			strncpy(BROWSER,tmp,(size_t)MAXPATH);
-			tmp[0]=(unsigned char)NULL;
+			tmp[0]=(uintptr_t)NULL;
 			freadline(file,tmp,MAXLINE);
 			strncpy(HELPURL,tmp,(size_t)MAXPATH);
-			tmp[0]=(unsigned char)NULL;
+			tmp[0]=(uintptr_t)NULL;
 			freadline(file,tmp,MAXLINE);
 			strncpy(GTKLPQCOM,tmp,(size_t)MAXPATH);
 			fscanf(file,"%i\n",&wantconst);
@@ -887,7 +887,7 @@ int addAllOptions(cups_option_t **optionsptr, int num_options) {
 	  num_options=cupsAddOption("collate","false",num_options,optionsptr);
 
 	/* Output */
-	if(wantRange == 1 && Range[0] != (unsigned char)NULL)
+	if(wantRange == 1 && Range[0] != (uintptr_t)NULL)
 		num_options=cupsAddOption("page-ranges",Range,num_options,optionsptr);
 	if(wantReverseOutputOrder == 1)
 		num_options=cupsAddOption("outputorder","reverse",num_options,optionsptr);
@@ -1070,14 +1070,14 @@ int addAllOptions(cups_option_t **optionsptr, int num_options) {
 
 	/* Special */
 	if(nox == 0) {
-		if(strcmp((unsigned char *)gtk_entry_get_text(GTK_ENTRY((GTK_COMBO(bannerFrameStopCombo)->entry))),"none") == 0) {
-			if(strcmp((unsigned char *)gtk_entry_get_text(GTK_ENTRY((GTK_COMBO(bannerFrameStartCombo)->entry))),"none") != 0) {
-				snprintf(tmp,(size_t)MAXOPTLEN,"%s",(unsigned char *)gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(bannerFrameStartCombo)->entry)));
+		if(strcmp((char *)gtk_entry_get_text(GTK_ENTRY((GTK_COMBO(bannerFrameStopCombo)->entry))),"none") == 0) {
+			if(strcmp((char *)gtk_entry_get_text(GTK_ENTRY((GTK_COMBO(bannerFrameStartCombo)->entry))),"none") != 0) {
+				snprintf(tmp,(size_t)MAXOPTLEN,"%s",(char *)gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(bannerFrameStartCombo)->entry)));
 				num_options=cupsAddOption("job-sheets",tmp,num_options,optionsptr);
 			}
 		}
 		else {
-			snprintf(tmp,(size_t)MAXOPTLEN,"%s,%s",(unsigned char *)gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(bannerFrameStartCombo)->entry)),(unsigned char *)gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(bannerFrameStopCombo)->entry)));
+			snprintf(tmp,(size_t)MAXOPTLEN,"%s,%s",(char *)gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(bannerFrameStartCombo)->entry)),(char *)gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(bannerFrameStopCombo)->entry)));
 			num_options=cupsAddOption("job-sheets",tmp,num_options,optionsptr);
 		}
 	}
@@ -1095,7 +1095,7 @@ int addAllOptions(cups_option_t **optionsptr, int num_options) {
 	}
 	if(wantraw == 1)
 		num_options=cupsParseOptions("raw",num_options,optionsptr);
-	if(ExtraOpt[0] != (unsigned char)NULL)
+	if(ExtraOpt[0] != (uintptr_t)NULL)
 		num_options=cupsParseOptions(ExtraOpt,num_options,optionsptr);	
 
 	return(num_options);
@@ -1114,7 +1114,7 @@ void setPrinterAsDefault(char *printername) {
 
 	instance=strchr(printername,'/');
 	if(instance != NULL)
-		*instance=(char)NULL;
+		*instance=(uintptr_t)NULL;
 		
 	num_dests=cupsGetDests(&dests);
 
@@ -1144,7 +1144,7 @@ int saveOptions(char *printername, int onlyglobal)
 	int num_options = 0;
 	cups_option_t *options;
 	cups_option_t **optionsptr = NULL;
-	unsigned char printpath[MAXPATH+1],globalpath[MAXPATH+1];
+	char printpath[MAXPATH+1],globalpath[MAXPATH+1];
 	FILE *file;
 	int num_printer;
 	cups_dest_t *all_printer;
@@ -1179,7 +1179,7 @@ int saveOptions(char *printername, int onlyglobal)
 	if(onlyglobal == 0) {
 		z1=strchr(printername,'/');
 		if(z1 != NULL) {
-			*z1=(char)NULL;
+			*z1=(uintptr_t)NULL;
 			snprintf(iprintername,(size_t)DEF_PRN_LEN,"%s\\%s",printername,z1+1);
 			*z1='/';
 			z1++;
@@ -1196,10 +1196,10 @@ int saveOptions(char *printername, int onlyglobal)
 		}
 	}	
 
-	printpath[0]=(unsigned char)NULL;
-	globalpath[0]=(unsigned char)NULL;
+	printpath[0]=(uintptr_t)NULL;
+	globalpath[0]=(uintptr_t)NULL;
 	
-	if(getenv("HOME")==(unsigned char)NULL)
+	if(getenv("HOME")==(uintptr_t)NULL)
 	{
 		if(DEBUG)
 			printf("ERROR: No Home-Variable set !\n");
@@ -1233,11 +1233,11 @@ int saveOptions(char *printername, int onlyglobal)
 		}
 		if(DEBUG)
 			printf("Saving Defaults for %s\n",printername);
-  	if(JobName[0]==(unsigned char)NULL)
+  	if(JobName[0]==(uintptr_t)NULL)
   		fprintf(file,"-\n");
   	else
     	fprintf(file,"%s\n",JobName);
-  	if(ExtraOpt[0]==(unsigned char)NULL)
+  	if(ExtraOpt[0]==(uintptr_t)NULL)
     	fprintf(file,"-\n");
   	else
     	fprintf(file,"%s\n",ExtraOpt);
@@ -1255,7 +1255,7 @@ int saveOptions(char *printername, int onlyglobal)
 		num_printer = cupsGetDests(&all_printer);
 		instance=strchr(printername,'/');
 		if(instance != NULL) {
-			*instance=(char)NULL;
+			*instance=(uintptr_t)NULL;
 			if(DEBUG)
 				printf("SAVE: Try to get printer: %s/%s\n",printername,instance+1);
 			act_printer = cupsGetDest(printername, instance+1, num_printer, all_printer);
@@ -1273,7 +1273,7 @@ int saveOptions(char *printername, int onlyglobal)
 					printf("SAVE: ERROR: Dest unknown (2) !\n");
 				emergency();
 			} else {		/* New Instance */
-				*instance=(char)NULL;
+				*instance=(uintptr_t)NULL;
 				num_printer = cupsAddDest(printername, instance+1, num_printer, &all_printer);
 				if(num_printer >= MAX_PRT) {
 					quick_message(str2str(_("Too many printers!")),2);
@@ -1378,7 +1378,7 @@ void setDefaults(void)
 	ppdTabSetDefaults();
 }
 
-int freadline(FILE *file,unsigned char *String, unsigned howmuch)
+int freadline(FILE *file,char *String, unsigned howmuch)
 {
         int i1,i2;
 				unsigned ct;
@@ -1391,11 +1391,11 @@ int freadline(FILE *file,unsigned char *String, unsigned howmuch)
                 i1=fgetc(file);
                 if((i1 != EOF) && (i1 != 10))
                 {
-                        *String++=(unsigned char)i1;
+                        *String++=(char)i1;
                 }
                 else
                 {
-                        *String=(unsigned char)NULL;
+                        *String=(uintptr_t)NULL;
                         break;
                 }
                 i2++;
@@ -1403,7 +1403,7 @@ int freadline(FILE *file,unsigned char *String, unsigned howmuch)
 									ct++;
 								}
 								else {
-									*String=(unsigned char)NULL;
+									*String=(uintptr_t)NULL;
 									return(i2);
 								}
 
@@ -1439,7 +1439,7 @@ int getPPDOpts(char *printername)
 	instance=strchr(printername,'/');
 	if(instance != NULL)
 	{
-		*instance=(char)NULL;
+		*instance=(uintptr_t)NULL;
 		if(DEBUG)
 			printf("Try to get printer: %s/%s\n",printername,instance+1);
 		act_printer = cupsGetDest(printername, instance+1, num_printer, all_printer);
@@ -1513,7 +1513,7 @@ int getPPDOpts(char *printername)
 
 void resetButton(GtkWidget *widget,gpointer data)
 {
-	unsigned char tmp[MAX_CPI_DIGITS+MAX_LPI_DIGITS+MAX_CPP_DIGITS+1];
+	char tmp[MAX_CPI_DIGITS+MAX_LPI_DIGITS+MAX_CPP_DIGITS+1];
 
         if(DEBUG)
                 printf("Reset: %s\n",(char *)data);
@@ -1613,7 +1613,7 @@ void resetButton(GtkWidget *widget,gpointer data)
 
         if(DEBUG)
         {
-                printf("PROG-ERROR: Unknown Reset Request: %s !\n",(unsigned char *)data);
+                printf("PROG-ERROR: Unknown Reset Request: %s !\n",(char *)data);
                 emergency();
         }
 }
@@ -1772,7 +1772,7 @@ void SaveFunc( GtkWidget *widget,gpointer instance)
 
 	z1=strchr(PrinterNames[PrinterChoice],'/');
 	if(z1 != NULL)
-		*z1 = (char)NULL;
+		*z1 = (uintptr_t)NULL;
 
 	if(strlen((char *)gtk_entry_get_text(GTK_ENTRY(instance))) != 0) {
 		snprintf(tmp,(size_t)DEF_PRN_LEN,"%s/%s",PrinterNames[PrinterChoice],(char *)gtk_entry_get_text(GTK_ENTRY(instance)));
@@ -1815,7 +1815,7 @@ void DelInstFunc( GtkWidget *widget,gpointer instance)
 	cups_dest_t *dest;	
 	GList *printerList=NULL;
 	char tmp[DEF_PRN_LEN+1];
-	unsigned char printpath[MAXPATH+1];
+	char printpath[MAXPATH+1];
 
 	num_dests=0;
 	dests=NULL;
@@ -1823,7 +1823,7 @@ void DelInstFunc( GtkWidget *widget,gpointer instance)
 
 	z1=strchr(PrinterNames[PrinterChoice],'/');
 	if(z1 != NULL)	
-		*z1=(char)NULL;
+		*z1=(uintptr_t)NULL;
 	strncpy(tmp,PrinterNames[PrinterChoice],(size_t)DEF_PRN_LEN);
 	if(z1 != NULL)
 		*z1='/';
@@ -1874,7 +1874,7 @@ void clearFileList(void)
 	if(DEBUG)
 		printf("Clear file list !\n");
   filesToPrintAnz=0;
-  filesToPrint[0][0]=(unsigned char)NULL;
+  filesToPrint[0][0]=(uintptr_t)NULL;
 	if(nox == 0)
 		gtk_clist_clear(GTK_CLIST(fileList));
 }
@@ -1884,13 +1884,14 @@ void PrintFunc( GtkWidget *widget,gpointer   data )
 	FILE *spool;
 	char tmp[MAXOPTLEN+1];
 	char tmppath[MAXPATH+1];
-	char *spoolfile,*z1;
+	char *z1;
 	int i1;
 	int num_options,jobid;
 	cups_option_t *options;
 	cups_option_t **optionsptr;	
 	const char *files[MAXPRINTFILES];
 	char tmpprn[DEF_PRN_LEN+1];
+  char *spoolfile;
 	
 	for(i1=0;i1<=filesToPrintAnz;i1++)
 		files[i1]=filesToPrint[i1];
@@ -1904,14 +1905,14 @@ void PrintFunc( GtkWidget *widget,gpointer   data )
 	snprintf(tmpprn,(size_t)DEF_PRN_LEN,"%s",PrinterNames[PrinterChoice]);
 	z1=strchr(tmpprn,'/');
 	if(z1 != NULL)
-		*z1=(char)NULL;
+		*z1=(uintptr_t)NULL;
 
 	if((ReallyPrint == 1) && (teststdin() == 0))
 	{
 		if(filesToPrintAnz > 0)
 		{
 			if(DEBUG)  printf("NumOpts-final(printing from file): %i\n",num_options);
-			if(JobName[0] != (unsigned char)NULL)
+			if(JobName[0] != (uintptr_t)NULL)
 			{
 					jobid=cupsPrintFiles(tmpprn,filesToPrintAnz,files,JobName,num_options,options);
 			}
@@ -1953,7 +1954,8 @@ void PrintFunc( GtkWidget *widget,gpointer   data )
                 if(DEBUG)  printf("NumOpts-final(printing from stdin): %i\n",num_options);
 
                 spoolfile=cupsTempFile(tmppath,sizeof(tmppath));
-                if(spoolfile == (char *)NULL)
+
+                if(spoolfile == (uintptr_t)NULL)
                 {
                         if(DEBUG)
                                 printf("Cannot create temporary spool file !");
@@ -1963,7 +1965,7 @@ void PrintFunc( GtkWidget *widget,gpointer   data )
 		{
 			if(DEBUG)
 				printf("Spoolfile: %s\n",tmppath);
-    			spool=fopen(spoolfile, "w");                                                                                     
+    	spool=fopen(spoolfile, "w");                                                                                     
 			if(spool==(FILE *)NULL)
 			{
 				if(DEBUG)
@@ -1972,7 +1974,6 @@ void PrintFunc( GtkWidget *widget,gpointer   data )
 			}
 			else
 			{
-                                                                                                                                                     
     				while ((i1 = fread(tmp, 1, sizeof(tmp), stdin)) > 0)                                                                                        
 					fwrite(tmp, 1, i1, spool);                                                                                                                    
     				i1 = ftell(spool);                                                                                                                                 
@@ -1984,7 +1985,7 @@ void PrintFunc( GtkWidget *widget,gpointer   data )
 					emergency();
 				}
 					
-					if(JobName[0] != (unsigned char)NULL)
+					if(JobName[0] != (uintptr_t)NULL)
 						jobid=cupsPrintFile(tmpprn,spoolfile,JobName,num_options,options);
 					else
 	          jobid=cupsPrintFile(tmpprn,spoolfile,str2str(_("(stdin)")),num_options,options);
@@ -2015,7 +2016,7 @@ void PrintFunc( GtkWidget *widget,gpointer   data )
 			g_print(" -o %s=%s",options[i1].name,options[i1].value);
 		}
 		g_print(" -P%s",PrinterNames[PrinterChoice]);
-		if(JobName[0] != (unsigned char)NULL)
+		if(JobName[0] != (uintptr_t)NULL)
 			g_print(" -J \"%s\"",JobName);
 		if(filesToPrintAnz > 0)
 		{
@@ -2286,7 +2287,7 @@ void instWinEntryChanged(GtkWidget *widget, gpointer data)
 
 	z1=strchr(PrinterNames[PrinterChoice],'/');
 	if(z1 != NULL)
-		*z1 = (char)NULL;
+		*z1 = (uintptr_t)NULL;
 	snprintf(tmp,(size_t)DEF_PRN_LEN,"%s/%s",PrinterNames[PrinterChoice],(char *)gtk_entry_get_text(GTK_ENTRY(widget)));
 	if(z1 != NULL)
 		 *z1 = '/';
@@ -2379,7 +2380,7 @@ void instWin(GtkWidget *widget, gpointer data)
 
 	z1=strchr(PrinterNames[PrinterChoice],'/');
 	if(z1 != NULL)
-		*z1=(char)NULL;
+		*z1=(uintptr_t)NULL;
 
 	printer=gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(printer),PrinterNames[PrinterChoice]);
