@@ -199,7 +199,7 @@ void outputOrderCheckChanged(GtkWidget *widget,gpointer data)
 
 void rangeTextChanged(GtkWidget *widget,gpointer data)
 {
-        unsigned char tmp[MAXRANGEENTRY+1];
+        char tmp[MAXRANGEENTRY+1];
         unsigned i1,flg=0;
 
         strncpy(tmp,gtk_editable_get_chars(GTK_EDITABLE(rangeText),0,-1),(size_t)MAXRANGEENTRY);
@@ -216,7 +216,7 @@ void rangeTextChanged(GtkWidget *widget,gpointer data)
                         break;
                 }
         }
-        if((flg==0) && tmp[0] != (unsigned char)NULL)
+        if((flg==0) && tmp[0] != (uintptr_t)NULL)
         {
                 strncpy(Range,tmp,(size_t)MAXRANGEENTRY);
                 if(DEBUG)
