@@ -49,7 +49,7 @@ GtkWidget *prettyCheck,*wrapCheck;
 
 void textTabSetDefaults(void)
 {
-	unsigned char tmp[MAX_CPI_DIGITS+MAX_LPI_DIGITS+MAX_CPP_DIGITS+MAX_MARGIN_DIGITS+5];
+	char tmp[MAX_CPI_DIGITS+MAX_LPI_DIGITS+MAX_CPP_DIGITS+MAX_MARGIN_DIGITS+5];
 
 	if(DEBUG)
 		printf("Get textTabDefaults\n");
@@ -115,13 +115,13 @@ void textTabSetDefaults(void)
 
 void textSizesChanged(GtkWidget *widget,gpointer data)
 {
-        unsigned char tmp[MAX_CPI_DIGITS+MAX_LPI_DIGITS+MAX_CPP_DIGITS+1];
+        char tmp[MAX_CPI_DIGITS+MAX_LPI_DIGITS+MAX_CPP_DIGITS+1];
         unsigned i1,flg=0;
 
-	tmp[0]=(unsigned char)NULL;
+	tmp[0]=(uintptr_t)NULL;
 
         if(DEBUG)
-                printf("textSizesChanged: %s->%s\n",(unsigned char *)data,tmp);
+                printf("textSizesChanged: %s->%s\n",(char *)data,tmp);
 
 	if(strcmp(data,"CPI")==0)
 	{
@@ -138,7 +138,7 @@ void textSizesChanged(GtkWidget *widget,gpointer data)
 	else
 	{
 		if(DEBUG)
-			printf("PROG-ERROR: Unknwon Text-Size change: %s !\n",(unsigned char *)data);
+			printf("PROG-ERROR: Unknwon Text-Size change: %s !\n",(char *)data);
 		emergency();
 	}
 
@@ -169,7 +169,7 @@ void textSizesChanged(GtkWidget *widget,gpointer data)
                 }
         }
 
-        if((flg==0) && tmp[0] != (unsigned char)NULL)
+        if((flg==0) && tmp[0] != (uintptr_t)NULL)
         {
 	        if(strcmp(data,"CPI")==0)
                 {
@@ -297,13 +297,13 @@ void textSizes(GtkWidget *container)
 
 void textMarginsChanged(GtkWidget *widget,gpointer data)
 {
-        unsigned char tmp[MAX_MARGIN_DIGITS+5];
+        char tmp[MAX_MARGIN_DIGITS+5];
         unsigned i1,flg=0;
 
-        tmp[0]=(unsigned char)NULL;
+        tmp[0]=(uintptr_t)NULL;
 
         if(DEBUG)
-                printf("textMarginsChanged: %s->%s\n",(unsigned char *)data,tmp);
+                printf("textMarginsChanged: %s->%s\n",(char *)data,tmp);
 
         if(strcmp(data,"Top")==0)
         {
@@ -324,7 +324,7 @@ void textMarginsChanged(GtkWidget *widget,gpointer data)
         else
         {
                 if(DEBUG)
-                        printf("PROG-ERROR: Unknwon Text-Margins change: %s !\n",(unsigned char *)data);
+                        printf("PROG-ERROR: Unknwon Text-Margins change: %s !\n",(char *)data);
                 emergency();
         }
 
@@ -360,7 +360,7 @@ void textMarginsChanged(GtkWidget *widget,gpointer data)
                         break;
                 }
         }
-        if((flg==0) && tmp[0] != (unsigned char)NULL)
+        if((flg==0) && tmp[0] != (uintptr_t)NULL)
         {
                 if(strcmp(data,"Top")==0)
                 {
