@@ -34,6 +34,7 @@
 #include <string.h>
 #include <ctype.h>
 #include <sys/types.h>
+#include <sys/stat.h>
 #include <dirent.h>
 #include <X11/Xlib.h>
 #include <libgen.h>
@@ -75,13 +76,13 @@ GtkWidget *dialog;
 
 int m_id_upd,c_id_upd,m_id_state,c_id_state;
 
-unsigned char PrinterNames[MAX_PRT][DEF_PRN_LEN+1];
-unsigned char PrinterInfos[MAX_PRT][MAXLINE+1];
-unsigned char PrinterLocations[MAX_PRT][MAXLINE+1];
+char PrinterNames[MAX_PRT][DEF_PRN_LEN+1];
+char PrinterInfos[MAX_PRT][MAXLINE+1];
+char PrinterLocations[MAX_PRT][MAXLINE+1];
 int PrinterNum;
 int PrinterChoice;
-unsigned char PrinterBannerStart[MAX_PRT][MAXLINE+1];
-unsigned char PrinterBannerEnd[MAX_PRT][MAXLINE+1];
+char PrinterBannerStart[MAX_PRT][MAXLINE+1];
+char PrinterBannerEnd[MAX_PRT][MAXLINE+1];
 
 unsigned int selectedJob;
 
@@ -99,7 +100,7 @@ int main(int argc,char *argv[])
 	GdkBitmap *mgtklpq_exit,*mgtklpq_move,*mgtklpq_prio, *mgtklpq_stop_job, *mgtklpq_stop_jobs;
 	GtkWidget *image;
 	int i1;
-	unsigned char Path[MAXPATH+1];
+	char Path[MAXPATH+1];
 	char *z1;
 	int queryIntervall=0;
 	int xpos,ypos;
@@ -113,12 +114,13 @@ int main(int argc,char *argv[])
 	int calledDisable;
 	int calledDisableCancel;
 	int calledReject;
+  struct stat snstat;
 
 #if GTK_MAJOR_VERSION != 1
 	progressBar=(GtkWidget *)NULL;
 #endif
 	dialog=(GtkWidget *)NULL;
-	reason[0]=(char)NULL;
+	reason[0]=(uintptr_t)NULL;
 
 	hasAskedPWD=0;
 	selectedJob=0;
@@ -232,11 +234,11 @@ int main(int argc,char *argv[])
 	}
 
 	/*--- Get Programm Options ---*/
-	DEF_PRN[0]=(unsigned char)NULL;
-	ServerName[0]=(char)NULL;
-	UserName[0]=(char)NULL;
-	Path[0]=(unsigned char)NULL;
-	passWord[0]=(char)NULL;
+	DEF_PRN[0]=(uintptr_t)NULL;
+	ServerName[0]=(uintptr_t)NULL;
+	UserName[0]=(uintptr_t)NULL;
+	Path[0]=(uintptr_t)NULL;
+	passWord[0]=(uintptr_t)NULL;
 	i1=getopt(argc,argv,GTKLPQ_ProgOpts);
 	while(i1 != -1)
 	{
@@ -292,7 +294,7 @@ int main(int argc,char *argv[])
           return(0);
         }
 			case 'S':
-				if(optarg == (char)NULL)
+				if(optarg == (uintptr_t)NULL)
 				{
 					exitOnError(str2str(_("This option requires an value !")), "", -1);
 					break;
@@ -334,7 +336,7 @@ int main(int argc,char *argv[])
 				if(strchr(optarg,'x') != NULL)
 				{
 					z1=strchr(optarg,'x');
-					*z1=(char)NULL;
+					*z1=(uintptr_t)NULL;
 					z1++;
 					xpos=atoi(optarg);
 					ypos=atoi(z1);
@@ -364,7 +366,7 @@ int main(int argc,char *argv[])
 	}
 
 	/* Try to get connected to Server */
-	if(ServerName[0]==(char)NULL)
+	if(ServerName[0]==(uintptr_t)NULL)
 	{
 		if(DEBUG)
 			printf("No Servername given, searching...\n");
@@ -390,9 +392,22 @@ int main(int argc,char *argv[])
 	{
 		if(DEBUG)
 			printf("connected\n");
-		snprintf(tmpenv,(size_t)MAX_SERVER_NAME+12,"CUPS_SERVER=%s",ServerName);
-		putenv(tmpenv);
-		cupsSetServer((const char *)ServerName);
+
+    if(stat(ServerName,&snstat) != 0) { 
+      if(DEBUG)
+        printf("PROG-ERROR: Cannot stat %s!\n",ServerName);
+    } else {
+      if(S_ISSOCK(snstat.st_mode)) {
+        strncpy(ServerName,"127.0.0.1",(size_t)MAX_SERVER_NAME);
+      } else {
+        printf("No socket\n");
+      }
+    }
+    
+    snprintf(tmpenv,(size_t)MAX_SERVER_NAME+12,"CUPS_SERVER=%s",ServerName);
+    putenv(tmpenv);
+    cupsSetServer((const char *)ServerName);
+
 	}
 	cupsLanguage=cupsLangDefault();
 
@@ -410,7 +425,7 @@ int main(int argc,char *argv[])
   if(DEBUG)
     printf("Default-Printer(2): %s\n",DEF_PRN);
 
-  if(DEF_PRN[0] == (unsigned char)NULL)
+  if(DEF_PRN[0] == (uintptr_t)NULL)
   {
     if(DEBUG)
       printf("PROG-ERROR: No Printer found to use for default !\n");
@@ -578,7 +593,7 @@ int main(int argc,char *argv[])
 			while(optind < argc)
 			{
 				i1=0;
-				while(PrinterNames[i1][0] != (char)NULL)
+				while(PrinterNames[i1][0] != (uintptr_t)NULL)
 				{
 					if(strcmp(PrinterNames[i1],argv[optind]) == 0)
 					{
