@@ -96,7 +96,7 @@ int PrinterChanged (GtkWidget * widget, gpointer data)
   if (DEBUG) 
     printf ("Printer changed: %i - %s\n", t,(char *) tmp);
 
-	if(tmp[0] == (char)NULL) {
+	if(tmp[0] == (uintptr_t)NULL) {
 		if(DEBUG)
 			printf("Skipping empty entrys\n");
 		return(0);
@@ -116,7 +116,7 @@ int PrinterChanged (GtkWidget * widget, gpointer data)
 	}
       i1++;
     }
-  while (PrinterNames[i1][0] != (unsigned char) NULL);
+  while (PrinterNames[i1][0] != (uintptr_t) NULL);
 
   if (strangeerrortrap == 0)
     {
@@ -523,8 +523,8 @@ int printQueueUpdate (GtkWidget * widget, gpointer data)
     {
 			z1=strchr(PrinterNames[PrinterChoice],'/');
 			if(z1 != NULL)
-				*z1=(char)NULL;		
-      if (PortString[0] != (char) NULL)
+				*z1=(uintptr_t)NULL;		
+      if (PortString[0] != (uintptr_t) NULL)
 				snprintf (resource, (size_t)MAX_URI, "ipp://%s:%s/printers/%s", ServerName, PortString, PrinterNames[PrinterChoice]);
       else
 				snprintf (resource, (size_t)MAX_URI, "ipp://%s/printers/%s", ServerName, PrinterNames[PrinterChoice]);
@@ -903,7 +903,7 @@ void queueFunc (GtkWidget * widget, gpointer data)
 		gtk_widget_show(labelr);
 
 		entry=gtk_entry_new();
-		if(reason[0] != (char)NULL)
+		if(reason[0] != (uintptr_t)NULL)
 			gtk_entry_set_text(GTK_ENTRY(entry),reason);
 		gtk_box_pack_start (GTK_BOX (vbox), entry, FALSE, FALSE, 0);
 		gtk_signal_connect(GTK_OBJECT(entry), "changed", GTK_SIGNAL_FUNC (reasonChanged), NULL);
@@ -1087,7 +1087,7 @@ int jobAttr(int job_id, int num_options, cups_option_t *options)
 	
 	if ((strlen (ServerName) + strlen (PortString) +  25) < MAX_URI)
 	{
-		if (PortString[0] != (char) NULL)
+		if (PortString[0] != (uintptr_t) NULL)
 			snprintf (uri, (size_t)MAX_URI, "ipp://%s:%s/jobs/%i", ServerName, PortString, job_id);
 		else
 			snprintf (uri, (size_t)MAX_URI, "ipp://%s/jobs/%i", ServerName, job_id);
@@ -1137,7 +1137,7 @@ void jobPrio (GtkWidget *dialog)
 
 	num_options=0;
 	prio=0;
-	TMPPRIO[0]=(char)NULL;
+	TMPPRIO[0]=(uintptr_t)NULL;
 	options=NULL;
 
 	gtk_spin_button_update(GTK_SPIN_BUTTON(prioSpin));
@@ -1250,10 +1250,10 @@ void cancelJob (GtkWidget * dialog)
 		z1=strchr(PrinterNames[PrinterChoice],'/');
 		z2=strchr(PrinterNames[PrtDlgSel],'/');
 		if(z1 != NULL)
-			*z1=(char)NULL;
+			*z1=(uintptr_t)NULL;
 		if(z2 != NULL)
-			*z2=(char)NULL;	
-	  if (PortString[0] != (char) NULL)
+			*z2=(uintptr_t)NULL;	
+	  if (PortString[0] != (uintptr_t) NULL)
 		{
 		  snprintf (uri, (size_t)MAX_URI, "ipp://%s:%s/printers/%s", ServerName, PortString,  PrinterNames[PrinterChoice]);
 			snprintf (touri,(size_t)MAX_URI, "ipp://%s:%s/printers/%s", ServerName, PortString,  PrinterNames[PrtDlgSel]);
@@ -1285,7 +1285,7 @@ void cancelJob (GtkWidget * dialog)
 	ippAddInteger(request, IPP_TAG_OPERATION, IPP_TAG_INTEGER, "job-id", job_id);
 
 	if((cancelmode == 5) || (cancelmode == 8)) {
-		if(reason[0] != (char)NULL)
+		if(reason[0] != (uintptr_t)NULL)
 			ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_TEXT,"printer-state-message", NULL, reason);
 	}	
 	
