@@ -72,12 +72,12 @@ int lastPrinterChoice;
 int passActive=0;
 char passWord[MAX_PASSLEN+1];
 char ServerName[MAX_SERVER_NAME+1];
-unsigned char DEF_PRN[DEF_PRN_LEN+1];
-unsigned char PrinterBannerStart[MAX_PRT][MAXLINE+1];
-unsigned char PrinterBannerEnd[MAX_PRT][MAXLINE+1];
-unsigned char PrinterInfos[MAX_PRT][MAXLINE+1];
-unsigned char PrinterLocations[MAX_PRT][MAXLINE+1];
-unsigned char PrinterNames[MAX_PRT][DEF_PRN_LEN+1];
+char DEF_PRN[DEF_PRN_LEN+1];
+char PrinterBannerStart[MAX_PRT][MAXLINE+1];
+char PrinterBannerEnd[MAX_PRT][MAXLINE+1];
+char PrinterInfos[MAX_PRT][MAXLINE+1];
+char PrinterLocations[MAX_PRT][MAXLINE+1];
+char PrinterNames[MAX_PRT][DEF_PRN_LEN+1];
 
 #if GTK_MAJOR_VERSION != 1
 GtkWidget *passwin;
@@ -209,17 +209,15 @@ void getPrinters(int loop)
 	unsigned droppedPrinters;
 	char TMPPATH[MAXPATH+1];
 	DIR *testdir;
-	DIR *testdir2;
-	DIR *testdir3;
 	FILE *testfile;
-	FILE *testfile2;
-	FILE *testfile3;
-	unsigned char ShowAllPrinter;
+	char allowdenyexists;
+	char ad;
 #if GTK_MAJOR_VERSION != 1
 	double progFrac=1.0, progress=1.0;
 #endif
 	droppedPrinters=0;
-	ShowAllPrinter=TRUE;
+	allowdenyexists=-1;	/* -1=undef, 0=allow dir exists, 1=only deny dir exists, 2=mechanismus deactive */
+	ad=1;								/* 1=printer is allowed, -1=printer is denied */
 
 	PrinterChoice=-1;
 	lastPrinterChoice=-1;
@@ -238,21 +236,24 @@ void getPrinters(int loop)
 	if(DEBUG)
         	printf("Number of Printers: %i\n",PrinterNum+1);
 
-snprintf(TMPPATH,(size_t)MAXPATH,"%s/%s/",DEF_GTKLPRC,GTKLPDENYDIR);
-testdir=opendir(TMPPATH);
-if (testdir != (DIR *)NULL) {
-  ShowAllPrinter=FALSE;
-  closedir(testdir); }
-snprintf(TMPPATH,(size_t)MAXPATH,"%s/%s/%s/",getenv("HOME"),GTKLPRC_USER,GTKLPACCEPTDIR);
-testdir2=opendir(TMPPATH);
-if (testdir2 != (DIR *)NULL) {
-  ShowAllPrinter=FALSE;
-  closedir(testdir2); }
-snprintf(TMPPATH,(size_t)MAXPATH,"%s/%s/",DEF_GTKLPRC,GTKLPACCEPTDIR);
-testdir3=opendir(TMPPATH);
-if (testdir3 != (DIR *)NULL) {
-  ShowAllPrinter=FALSE;
-  closedir(testdir3); }
+	snprintf(TMPPATH,(size_t)MAXPATH,"%s/%s/",DEF_GTKLPRC,GTKLPACCEPTDIR);
+	testdir=opendir(TMPPATH);
+	if (testdir != (DIR *)NULL) {		/* system/allow exists */
+		allowdenyexists=0;
+		ad=-1;												/* default is deny all, but... */
+		closedir(testdir);
+	} else {												/* system/allow does not exist */
+		snprintf(TMPPATH,(size_t)MAXPATH,"%s/%s/",DEF_GTKLPRC,GTKLPDENYDIR);
+		testdir=opendir(TMPPATH);
+		if (testdir != (DIR *)NULL) {	/* no system/allow but system/deny */
+			allowdenyexists=1;
+			ad=1;												/* default is allow all, but... */
+			closedir(testdir);
+		}	else {
+			allowdenyexists=2;					/* no system/allow, no system/deny */
+			ad=1;												/* all printers are allowed (ok, stay allowed...) */
+		}
+	}
 
 #if GTK_MAJOR_VERSION != 1
 	progFrac=0.8/PrinterNum;
@@ -281,35 +282,59 @@ if (testdir3 != (DIR *)NULL) {
 		else
 			snprintf(PrinterNames[i1-droppedPrinters],(size_t)DEF_PRN_LEN,"%s/%s",dests[i1].name,dests[i1].instance);
 
-			
-snprintf(TMPPATH,(size_t)MAXPATH,"%s/%s/%s",DEF_GTKLPRC,GTKLPDENYDIR,PrinterNames[i1-droppedPrinters]);
-testfile3=fopen(TMPPATH,"r");
-snprintf(TMPPATH,(size_t)MAXPATH,"%s/%s/%s/%s",getenv("HOME"),GTKLPRC_USER,GTKLPACCEPTDIR,PrinterNames[i1-droppedPrinters]);
-testfile2=fopen(TMPPATH,"r");
-snprintf(TMPPATH,(size_t)MAXPATH,"%s/%s/%s",DEF_GTKLPRC,GTKLPACCEPTDIR,PrinterNames[i1-droppedPrinters]);
-testfile=fopen(TMPPATH,"r");
-if((((!ShowAllPrinter) && ((testfile == (FILE *)NULL) && (testfile2 == (FILE *)NULL))) || (testfile3 != (FILE *)NULL) )) {
-	droppedPrinters++;
-	if(testfile != (FILE *) NULL) fclose(testfile);
-	if(testfile2 != (FILE *) NULL) fclose(testfile2);
-	if(testfile3 != (FILE *) NULL) fclose(testfile3);
-} else {
-	if(testfile != (FILE *) NULL) fclose(testfile);
-	if(testfile2 != (FILE *) NULL) fclose(testfile2);
-	if(testfile3 != (FILE *) NULL) fclose(testfile3);
-			
-		if((dests[i1].is_default == 1) & (DEF_PRN[0] == (unsigned char)NULL))
+	if(allowdenyexists == 0) {
+		snprintf(TMPPATH,(size_t)MAXPATH,"%s/%s/%s",DEF_GTKLPRC,GTKLPACCEPTDIR,PrinterNames[i1-droppedPrinters]);
+		testfile=fopen(TMPPATH,"r");
+		if(testfile == (FILE *)NULL) {	/* printer is not in system/allow */
+				ad=-1;											/* printer is denied */	
+		} else {												/* printer stays allowed */
+			fclose(testfile);
+			snprintf(TMPPATH,(size_t)MAXPATH,"%s/%s/%s/%s",getenv("HOME"),GTKLPRC_USER,GTKLPDENYDIR,PrinterNames[i1-droppedPrinters]);
+			testfile=fopen(TMPPATH,"r");	
+			if(testfile != (FILE *)NULL) {	/* printer denied by user */
+				fclose(testfile);
+				ad=-1;
+			} else {												/* printer allowed */
+				ad=1;
+			}	
+		}
+	}
+
+	if(allowdenyexists == 1) {
+		snprintf(TMPPATH,(size_t)MAXPATH,"%s/%s/%s",DEF_GTKLPRC,GTKLPDENYDIR,PrinterNames[i1-droppedPrinters]);
+		testfile=fopen(TMPPATH,"r");
+		if(testfile != (FILE *)NULL) {	/* printer is denied by system */
+			fclose(testfile);
+			ad=-1;
+		} else {
+			snprintf(TMPPATH,(size_t)MAXPATH,"%s/%s/%s/%s",getenv("HOME"),GTKLPRC_USER,GTKLPDENYDIR,PrinterNames[i1-droppedPrinters]);
+			testfile=fopen(TMPPATH,"r");
+			if(testfile != (FILE *)NULL) {  /* printer denied by user */
+				fclose(testfile);
+				ad=-1;
+			} else {                        /* printer allowed */
+				ad=1;
+			}
+		}
+	}
+
+
+
+	if(ad == -1) {	/* printer is denied */
+		droppedPrinters++;
+	} else {
+		if((dests[i1].is_default == 1) & (DEF_PRN[0] == (uintptr_t)NULL))
 		{
 			if(DEBUG)
 				printf("---->Default-Printer\n");
-			if(dests[i1].instance == (unsigned char)NULL) { 
+			if(dests[i1].instance == (uintptr_t)NULL) { 
 				strncpy(DEF_PRN,dests[i1].name,(size_t)DEF_PRN_LEN);
 			}
 			else {
 				snprintf(DEF_PRN,(size_t)DEF_PRN_LEN,"%s/%s",dests[i1].name,dests[i1].instance);
 			}		
 		}
-		if(DEF_PRN[0] != (unsigned char)NULL)
+		if(DEF_PRN[0] != (uintptr_t)NULL)
 		{
 			if(dests[i1].instance != NULL)
 				snprintf(tmpprn,(size_t)DEF_PRN_LEN,"%s/%s",dests[i1].name,dests[i1].instance);
@@ -370,7 +395,7 @@ if((((!ShowAllPrinter) && ((testfile == (FILE *)NULL) && (testfile2 == (FILE *)N
 		ippDelete(response);
         }
 
-}
+	}
 
 	if(PrinterNum < 0)
 	{
@@ -378,7 +403,7 @@ if((((!ShowAllPrinter) && ((testfile == (FILE *)NULL) && (testfile2 == (FILE *)N
 			printf("PROG-ERROR: No Printers found !\n");
 		exitOnError(str2str(_("No printers found !")),"",-2);
 	}
-	if(DEF_PRN[0]==(unsigned char)NULL)
+	if(DEF_PRN[0]==(uintptr_t)NULL)
 	{
 		if(DEBUG)
 			printf("No Default Printer yet, using %s\n",PrinterNames[0]);
@@ -392,11 +417,20 @@ if((((!ShowAllPrinter) && ((testfile == (FILE *)NULL) && (testfile2 == (FILE *)N
 			gtklp_fatal_end(str2str(_("The given printer does not exist!")));
 		}
 		quick_message(str2str(_("The given printer does not exist!")),2);
-		DEF_PRN[0]=(unsigned char)NULL;
+		DEF_PRN[0]=(uintptr_t)NULL;
 		getPrinters(loop+1);
 	}
 
-PrinterNum-=droppedPrinters;
+	/* decrease for hidden printers */
+	PrinterNum-=droppedPrinters;
+
+	/* any visible printers left? */
+	if(PrinterNum < 0)
+	{
+		if(DEBUG)
+			printf("PROG-ERROR: No Printers found !\n");
+		exitOnError(str2str(_("No printers found !")),"",-2);
+	}
 }
 
 void gtklp_fatal_end(char *text)
@@ -463,7 +497,7 @@ const char *getPass (const char *prompt)
 
 	hasAskedPWD=1;
 
-	if(passWord[0] != (char)NULL)
+	if(passWord[0] != (uintptr_t)NULL)
 	{
 		if(DEBUG)
 			printf("Password already set to %s\n",passWord);
@@ -599,7 +633,7 @@ const char *getPass (const char *prompt)
 	if(DEBUG)
 		printf("Passwort set to:%s\n",passWord);
 
-	if(UserName[0] != (char)NULL)
+	if(UserName[0] != (uintptr_t)NULL)
 		cupsSetUser(UserName);
 
 	return(passWord);
