@@ -40,12 +40,12 @@ extern int nox;
 extern int PrinterChoice;
 extern int PrinterNum;
 extern int lastPrinterChoice;
-extern unsigned char DEF_PRN[DEF_PRN_LEN+1];
-extern unsigned char PrinterBannerStart[MAX_PRT][MAXLINE+1];
-extern unsigned char PrinterBannerEnd[MAX_PRT][MAXLINE+1];
-extern unsigned char PrinterInfos[MAX_PRT][MAXLINE+1];
-extern unsigned char PrinterLocations[MAX_PRT][MAXLINE+1];
-extern unsigned char PrinterNames[MAX_PRT][DEF_PRN_LEN+1];
+extern char DEF_PRN[DEF_PRN_LEN+1];
+extern char PrinterBannerStart[MAX_PRT][MAXLINE+1];
+extern char PrinterBannerEnd[MAX_PRT][MAXLINE+1];
+extern char PrinterInfos[MAX_PRT][MAXLINE+1];
+extern char PrinterLocations[MAX_PRT][MAXLINE+1];
+extern char PrinterNames[MAX_PRT][DEF_PRN_LEN+1];
 extern char ServerName[MAX_SERVER_NAME+1];
 extern char UserName[MAX_USERNAME+1];
 extern char passWord[MAX_PASSLEN+1];
